<?php

namespace Property\Property\Policies;

use Litepie\User\Contracts\UserPolicy;
use Property\Property\Models\PropertyLists;

class PropertyListsPolicy
{

    /**
     * Determine if the given user can view the property_lists.
     *
     * @param UserPolicy $user
     * @param PropertyLists $property_lists
     *
     * @return bool
     */
    public function view(UserPolicy $user, PropertyLists $property_lists)
    {
        if ($user->canDo('property.property_lists.view') && $user->isAdmin()) {
            return true;
        }

        return $property_lists->user_id == user_id() && $property_lists->user_type == user_type();
    }

    /**
     * Determine if the given user can create a property_lists.
     *
     * @param UserPolicy $user
     * @param PropertyLists $property_lists
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('property.property_lists.create');
    }

    /**
     * Determine if the given user can update the given property_lists.
     *
     * @param UserPolicy $user
     * @param PropertyLists $property_lists
     *
     * @return bool
     */
    public function update(UserPolicy $user, PropertyLists $property_lists)
    {
        if ($user->canDo('property.property_lists.edit') && $user->isAdmin()) {
            return true;
        }

        return $property_lists->user_id == user_id() && $property_lists->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given property_lists.
     *
     * @param UserPolicy $user
     * @param PropertyLists $property_lists
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PropertyLists $property_lists)
    {
        return $property_lists->user_id == user_id() && $property_lists->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given property_lists.
     *
     * @param UserPolicy $user
     * @param PropertyLists $property_lists
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PropertyLists $property_lists)
    {
        if ($user->canDo('property.property_lists.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property_lists.
     *
     * @param UserPolicy $user
     * @param PropertyLists $property_lists
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PropertyLists $property_lists)
    {
        if ($user->canDo('property.property_lists.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
